@@ -1,5 +1,4 @@
-
-'Generated protocol buffer code.'
+"""Generated protocol buffer code."""
 from google.protobuf import descriptor as _descriptor
 from google.protobuf import descriptor_pool as _descriptor_pool
 from google.protobuf import message as _message
@@ -13,10 +12,10 @@ Txs = _reflection.GeneratedProtocolMessageType('Txs', (_message.Message,), {'DES
 _sym_db.RegisterMessage(Txs)
 Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {'DESCRIPTOR': _MESSAGE, '__module__': 'tendermint.mempool.types_pb2'})
 _sym_db.RegisterMessage(Message)
-if (_descriptor._USE_C_DESCRIPTORS == False):
+if _descriptor._USE_C_DESCRIPTORS == False:
     DESCRIPTOR._options = None
     DESCRIPTOR._serialized_options = b'Z9github.com/tendermint/tendermint/proto/tendermint/mempool'
     _TXS._serialized_start = 54
     _TXS._serialized_end = 72
     _MESSAGE._serialized_start = 74
-    _MESSAGE._serialized_end = 130
+    _MESSAGE._serialized_end = 130
\ No newline at end of file
